@@ -72,7 +72,7 @@ class PayloadCodec:
         trusted_issuers: typing.Optional[typing.Set[str]] = None,
         content_encryption: str = "A256GCM",
         signing_keys: list[str | IKeySpecification] | None = None,
-        encryption_keys: list[str] | None = None,
+        encryption_keys: list[str | IKeySpecification] | None = None,
         allow_compact: bool = True,
         allow_flattened: bool = True
     ):
